==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/text/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.text;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.text package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.text
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TextsType }
     * 
     */
    public TextsType createTextsType() {
        return new TextsType();
    }

    /**
     * Create an instance of {@link TextType }
     * 
     */
    public TextType createTextType() {
        return new TextType();
    }

    /**
     * Create an instance of {@link LinkType }
     * 
     */
    public LinkType createLinkType() {
        return new LinkType();
    }

    /**
     * Create an instance of {@link ParagraphType }
     * 
     */
    public ParagraphType createParagraphType() {
        return new ParagraphType();
    }

    /**
     * Create an instance of {@link WordType }
     * 
     */
    public WordType createWordType() {
        return new WordType();
    }

    /**
     * Create an instance of {@link ContentType }
     * 
     */
    public ContentType createContentType() {
        return new ContentType();
    }

    /**
     * Create an instance of {@link WordContentType }
     * 
     */
    public WordContentType createWordContentType() {
        return new WordContentType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/text/ObjectFactory.java <==

package net.webpdf.wsclient.schema.extraction.text;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.webpdf.wsclient.schema.extraction.text package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.webpdf.wsclient.schema.extraction.text
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TextsType }
     * 
     * @return
     *     the new instance of {@link TextsType }
     */
    public TextsType createTextsType() {
        return new TextsType();
    }

    /**
     * Create an instance of {@link TextType }
     * 
     * @return
     *     the new instance of {@link TextType }
     */
    public TextType createTextType() {
        return new TextType();
    }

    /**
     * Create an instance of {@link LinkType }
     * 
     * @return
     *     the new instance of {@link LinkType }
     */
    public LinkType createLinkType() {
        return new LinkType();
    }

    /**
     * Create an instance of {@link ParagraphType }
     * 
     * @return
     *     the new instance of {@link ParagraphType }
     */
    public ParagraphType createParagraphType() {
        return new ParagraphType();
    }

    /**
     * Create an instance of {@link WordType }
     * 
     * @return
     *     the new instance of {@link WordType }
     */
    public WordType createWordType() {
        return new WordType();
    }

    /**
     * Create an instance of {@link ContentType }
     * 
     * @return
     *     the new instance of {@link ContentType }
     */
    public ContentType createContentType() {
        return new ContentType();
    }

    /**
     * Create an instance of {@link WordContentType }
     * 
     * @return
     *     the new instance of {@link WordContentType }
     */
    public WordContentType createWordContentType() {
        return new WordContentType();
    }

    /**
     * Create an instance of {@link RectangleType }
     * 
     * @return
     *     the new instance of {@link RectangleType }
     */
    public RectangleType createRectangleType() {
        return new RectangleType();
    }

}
